@@ -1,7 +1,7 @@
 //! The [`Output`] trait that defines all possible outputs of [`cmd!`],
 //! [`cmd_unit!`] and [`cmd_result!`].
 
-use crate::{config::Config, error::Error, RunResult};
+use crate::{config::Config, error::Error, run_result::RunResult};
 use std::{process::ExitStatus, sync::Arc};
 
 /// All possible return types of [`cmd!`], [`cmd_unit!`] or
